@@ -1,6 +1,6 @@
 # kas - setup tool for bitbake based projects
 #
-# Copyright (c) Siemens AG, 2017-2020
+# Copyright (c) Siemens AG, 2017-2021
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -28,29 +28,38 @@ from .repos import Repo
 from .includehandler import IncludeHandler, IncludeException
 
 __license__ = 'MIT'
-__copyright__ = 'Copyright (c) Siemens AG, 2017-2018'
+__copyright__ = 'Copyright (c) Siemens AG, 2017-2021'
+
+CONFIG_YAML_FILE = '.config.yaml'
 
 
 class Config:
     """
         Implements the kas configuration based on config files.
     """
-    def __init__(self, filename, target=None, task=None):
+    def __init__(self, ctx, filename, target=None, task=None):
         self._override_target = target
         self._override_task = task
         self._config = {}
-        self.filenames = [os.path.abspath(configfile)
-                          for configfile in filename.split(':')]
+        if filename:
+            self.filenames = [os.path.abspath(configfile)
+                              for configfile in filename.split(':')]
+            self.top_repo_path = Repo.get_root_path(
+                os.path.dirname(self.filenames[0]))
 
-        repo_paths = [Repo.get_root_path(os.path.dirname(configfile),
-                                         fallback=False)
-                      for configfile in self.filenames]
-        if len(set(repo_paths)) > 1:
-            raise IncludeException('All concatenated config files must '
-                                   'belong to the same repository or all '
-                                   'must be outside of versioning control')
+            repo_paths = [Repo.get_root_path(os.path.dirname(configfile),
+                                             fallback=False)
+                          for configfile in self.filenames]
 
-        self.handler = IncludeHandler(self.filenames)
+            if len(set(repo_paths)) > 1:
+                raise IncludeException('All concatenated config files must '
+                                       'belong to the same repository or all '
+                                       'must be outside of versioning control')
+        else:
+            self.filenames = [os.path.join(ctx.kas_work_dir, CONFIG_YAML_FILE)]
+            self.top_repo_path = os.getcwd()
+
+        self.handler = IncludeHandler(self.filenames, self.top_repo_path)
         self.repo_dict = self._get_repo_dict()
 
     def get_build_system(self):
@@ -88,13 +97,12 @@ class Config:
         repo_config_dict = self._config.get('repos', {})
         repo_defaults = self._config.get('defaults', {}).get('repos', {})
         repo_dict = {}
-        repo_fallback_path = os.path.dirname(self.filenames[0])
         for repo in repo_config_dict:
             repo_config_dict[repo] = repo_config_dict[repo] or {}
             repo_dict[repo] = Repo.factory(repo,
                                            repo_config_dict[repo],
                                            repo_defaults,
-                                           repo_fallback_path)
+                                           self.top_repo_path)
 
         return repo_dict
 
