@@ -1,6 +1,6 @@
 # kas - setup tool for bitbake based projects
 #
-# Copyright (c) Siemens AG, 2017-2018
+# Copyright (c) Siemens AG, 2017-2021
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -37,7 +37,7 @@ from . import __file_version__, __compatible_file_version__
 from . import CONFIGSCHEMA
 
 __license__ = 'MIT'
-__copyright__ = 'Copyright (c) Siemens AG, 2017-2018'
+__copyright__ = 'Copyright (c) Siemens AG, 2017-2021'
 
 
 class LoadConfigException(Exception):
@@ -93,6 +93,10 @@ def load_config(filename):
                                           __file_version__, version_value),
                                   filename)
 
+    if config.get('proxy_config'):
+        logging.warning('Obsolete ''proxy_config'' detected. '
+                        'This has no effect and will be rejected soon.')
+
     return config
 
 
@@ -110,20 +114,18 @@ class IncludeHandler:
         key containing a list of includes.
 
         The includes can be specified in two ways: as a string
-        containing the relative path from the current file or as a
-        dictionary. The dictionary should have a 'file' key containing
-        the relative path to the include file and optionally a 'repo'
-        key containing the key of the repository. If the 'repo' key is
-        missing the value of the 'file' key, it is treated the same as if
-        just a string was defined, meaning the path is relative to the
-        current config file. Otherwise it is interpreted relative to
-        the repository path.
+        containing the path, relative to the repository root from the
+        current file, or as a dictionary. The dictionary must have a
+        'file' key containing the path to the include file and a 'repo'
+        key containing the key of the repository. The path is interpreted
+        relative to the repository root path.
 
         The includes are read and merged from the deepest level upwards.
     """
 
-    def __init__(self, top_files):
+    def __init__(self, top_files, top_repo_path):
         self.top_files = top_files
+        self.top_repo_path = top_repo_path
 
     def get_config(self, repos=None):
         """
@@ -139,7 +141,7 @@ class IncludeHandler:
 
         repos = repos or {}
 
-        def _internal_include_handler(filename):
+        def _internal_include_handler(filename, repo_path):
             """
             Recursively loads include files and finds missing repos.
 
@@ -150,7 +152,6 @@ class IncludeHandler:
             header:
               includes:
                 - include1.yml
-                - file: include2.yml
                 - repo: repo1
                   file: include-repo1.yml
                 - repo: repo2
@@ -181,20 +182,26 @@ class IncludeHandler:
                         includefile = include
                     else:
                         includefile = os.path.abspath(
-                            os.path.join(
-                                os.path.dirname(filename),
-                                include))
-                    (cfg, rep) = _internal_include_handler(includefile)
+                            os.path.join(repo_path, include))
+                        if not os.path.exists(includefile):
+                            alternate = os.path.abspath(
+                                os.path.join(os.path.dirname(filename),
+                                             include))
+                            if os.path.exists(alternate):
+                                logging.warning(
+                                    'Falling back to file-relative addressing '
+                                    'of local include "%s"', include)
+                                logging.warning(
+                                    'Update your layer to repo-relative '
+                                    'addressing to avoid this warning')
+                                includefile = alternate
+                    (cfg, rep) = _internal_include_handler(includefile,
+                                                           repo_path)
                     configs.extend(cfg)
                     missing_repos.extend(rep)
                 elif isinstance(include, Mapping):
                     includerepo = include.get('repo', None)
-                    if includerepo is not None:
-                        includedir = repos.get(includerepo, None)
-                    else:
-                        raise IncludeException(
-                            '"repo" is not specified: {}'
-                            .format(include))
+                    includedir = repos.get(includerepo, None)
                     if includedir is not None:
                         try:
                             includefile = include['file']
@@ -202,11 +209,10 @@ class IncludeHandler:
                             raise IncludeException(
                                 '"file" is not specified: {}'
                                 .format(include))
+                        abs_includedir = os.path.abspath(includedir)
                         (cfg, rep) = _internal_include_handler(
-                            os.path.abspath(
-                                os.path.join(
-                                    includedir,
-                                    includefile)))
+                            os.path.join(abs_includedir, includefile),
+                            abs_includedir)
                         configs.extend(cfg)
                         missing_repos.extend(rep)
                     else:
@@ -257,9 +263,12 @@ class IncludeHandler:
         configs = []
         missing_repos = []
         for configfile in self.top_files:
-            cfgs, reps = _internal_include_handler(configfile)
+            cfgs, reps = _internal_include_handler(configfile,
+                                                   self.top_repo_path)
             configs.extend(cfgs)
-            missing_repos.extend(reps)
+            for repo in reps:
+                if repo not in missing_repos:
+                    missing_repos.append(repo)
 
         config = functools.reduce(_internal_dict_merge,
                                   map(lambda x: x[1], configs))
