@@ -50,14 +50,15 @@ class Macro:
                 SetupDir(),
             ]
 
-            if 'SSH_PRIVATE_KEY' in os.environ:
+            if ('SSH_PRIVATE_KEY' in os.environ
+                    or 'SSH_PRIVATE_KEY_FILE' in os.environ):
                 self.setup_commands.append(SetupSSHAgent())
 
             self.setup_commands += [
+                SetupHome(),
                 InitSetupRepos(),
                 repo_loop,
                 FinishSetupRepos(),
-                SetupHome(),
                 ReposApplyPatches(),
                 SetupEnviron(),
                 WriteBBConfig(),
@@ -65,7 +66,9 @@ class Macro:
         else:
             self.setup_commands = []
 
-        if use_common_cleanup and 'SSH_PRIVATE_KEY' in os.environ:
+        if (use_common_cleanup
+                and ('SSH_PRIVATE_KEY' in os.environ
+                     or 'SSH_PRIVATE_KEY_FILE' in os.environ)):
             self.cleanup_commands = [
                 CleanupSSHAgent(),
             ]
@@ -253,6 +256,8 @@ class WriteBBConfig(Command):
                     sorted(layer for repo in ctx.config.get_repos()
                            for layer in repo.layers)))
                 fds.write('"\n')
+                fds.write('BBPATH ?= "${TOPDIR}"\n')
+                fds.write('BBFILES ??= ""\n')
 
         def _write_local_conf(ctx):
             filename = ctx.build_dir + '/conf/local.conf'
