@@ -163,6 +163,9 @@ def repos_fetch(repos):
     """
         Fetches the list of repositories to the kas_work_dir.
     """
+    if len(repos) == 0:
+        return
+
     tasks = []
     for repo in repos:
         tasks.append(asyncio.ensure_future(repo.fetch_async()))
@@ -179,6 +182,9 @@ def repos_apply_patches(repos):
     """
         Applies the patches to the repositories.
     """
+    if len(repos) == 0:
+        return
+
     tasks = []
     for repo in repos:
         tasks.append(asyncio.ensure_future(repo.apply_patches_async()))
@@ -268,6 +274,15 @@ def get_build_environ(build_system):
     return env
 
 
+def ssh_add_key_file(env, key_path):
+    """
+        Adds an ssh key file to the ssh-agent
+    """
+    with open(key_path) as f:
+        key = f.read()
+        ssh_add_key(env, key)
+
+
 def ssh_add_key(env, key):
     """
         Adds an ssh key to the ssh-agent
@@ -307,20 +322,32 @@ def ssh_setup_agent(envkeys=None):
         Starts the ssh-agent
     """
     env = get_context().environ
-    envkeys = envkeys or ['SSH_PRIVATE_KEY']
+    envkeys = envkeys or ['SSH_PRIVATE_KEY', 'SSH_PRIVATE_KEY_FILE']
     output = os.popen('ssh-agent -s').readlines()
     for line in output:
         matches = re.search(r"(\S+)\=(\S+)\;", line)
         if matches:
             env[matches.group(1)] = matches.group(2)
 
+    found = False
     for envkey in envkeys:
-        key = os.environ.get(envkey)
-        if key:
-            logging.info("adding SSH key")
-            ssh_add_key(env, key)
+        if envkey == 'SSH_PRIVATE_KEY_FILE':
+            key_path = os.environ.get(envkey)
+            if key_path:
+                found = True
+                logging.info("adding SSH key")
+                ssh_add_key_file(env, key_path)
         else:
-            logging.warning('%s is missing', envkey)
+            key = os.environ.get(envkey)
+            if key:
+                found = True
+                logging.info("adding SSH key")
+                ssh_add_key(env, key)
+
+    if found is not True:
+        warning = "None of the following environment keys were set: " + \
+            ", ".join(envkeys)
+        logging.warning(warning)
 
 
 def ssh_no_host_key_check():
@@ -328,7 +355,35 @@ def ssh_no_host_key_check():
         Disables ssh host key check
     """
     home = os.path.expanduser('~')
-    if not os.path.exists(home + '/.ssh'):
-        os.mkdir(home + '/.ssh')
-    with open(home + '/.ssh/config', 'w') as fds:
-        fds.write('Host *\n\tStrictHostKeyChecking no\n\n')
+    ssh_dir = home + '/.ssh'
+    if not os.path.exists(ssh_dir):
+        os.mkdir(ssh_dir)
+    ssh_config = ssh_dir + "/config"
+    generated_content = 'Host *\n\tStrictHostKeyChecking no\n\n'
+    try:
+        with open(ssh_config, 'x') as fds:
+            fds.write(generated_content)
+    except FileExistsError:
+        with open(ssh_config, 'r') as fds:
+            content = fds.read()
+        if content != generated_content:
+            logging.warning("%s already exists, "
+                            "not touching it to disable StrictHostKeyChecking",
+                            ssh_config)
+
+
+def setup_parser_common_args(parser):
+    parser.add_argument('config',
+                        help='Config file, using .config.yaml if none is '
+                        'specified and using the current directory as '
+                        'repository anchor',
+                        nargs='?')
+    parser.add_argument('--skip',
+                        help='Skip build steps',
+                        default=[])
+    parser.add_argument('--force-checkout', action='store_true',
+                        help='Always checkout the desired refspec of each '
+                        'repository, discarding any local changes')
+    parser.add_argument('--update', action='store_true',
+                        help='Pull new upstream changes to the desired '
+                        'refspec even if it is already checked out locally')
