@@ -55,9 +55,11 @@
 
 import logging
 import subprocess
+import sys
 from kas.context import create_global_context
 from kas.config import Config
 from kas.libcmds import Macro, Command
+from kas.libkas import setup_parser_common_args
 
 __license__ = 'MIT'
 __copyright__ = 'Copyright (c) Siemens AG, 2017-2018'
@@ -71,12 +73,13 @@ class ForAllRepos:
 
     @classmethod
     def setup_parser(cls, parser):
+        setup_parser_common_args(parser)
         parser.add_argument('command',
                             help='Command to be executed as a string.')
 
     def run(self, args):
         ctx = create_global_context(args)
-        ctx.config = Config(args.config)
+        ctx.config = Config(ctx, args.config)
 
         macro = Macro()
         macro.add(ForAllReposCommand(args.command))
@@ -97,7 +100,7 @@ class ForAllReposCommand(Command):
                 **ctx.environ,
                 'KAS_REPO_NAME': repo.name,
                 'KAS_REPO_PATH': repo.path,
-                'KAS_REPO_URL': repo.url or '',
+                'KAS_REPO_URL': '' if repo.operations_disabled else repo.url,
                 'KAS_REPO_REFSPEC': repo.refspec or '',
             }
             logging.info('%s$ %s', repo.path, self.command)
@@ -105,6 +108,7 @@ class ForAllReposCommand(Command):
                                       env=env)
             if retcode != 0:
                 logging.error('Command failed with return code %d', retcode)
+                sys.exit(retcode)
 
 
 __KAS_PLUGINS__ = [ForAllRepos]
