@@ -60,3 +60,10 @@ def test_layers_exclude(dokas):
     with open('build/conf/bblayers.conf', 'r') as f:
         for line in f:
             assert('test_layers/kas2' not in line)
+
+
+def test_layers_strip_dot(dokas):
+    with open('build/conf/bblayers.conf', 'r') as f:
+        lines = f.readlines()
+        assert(any('test_layers/kas3 ' in x for x in lines))
+        assert(any('test_layers/kas3/meta-bar' in x for x in lines))
